@@ -11,6 +11,8 @@ from muutils.misc import str_to_numeric
 _EPSILON: float = 1e-10
 
 Number = Union[float, int]
+# TODO: make this also work with decimals, fractions, numpy types, etc.
+# except we must somehow avoid importing them? idk
 
 _EMPTY_INTERVAL_ARGS: tuple[Number, Number, bool, bool, set[Number]] = (
     math.nan,
@@ -72,9 +74,9 @@ class Interval:
             if len(args) == 1 and isinstance(
                 args[0], (list, tuple, Sequence, Iterable)
             ):
-                assert (
-                    len(args[0]) == 2
-                ), "if arg is a list or tuple, it must have length 2"
+                assert len(args[0]) == 2, (
+                    "if arg is a list or tuple, it must have length 2"
+                )
                 self.lower = args[0][0]
                 self.upper = args[0][1]
                 # Determine closure type based on the container type
@@ -268,9 +270,9 @@ class Interval:
             # empty set
             if input_str == "∅":
                 return cls.get_empty()
-            assert input_str.startswith("{") and input_str.endswith(
-                "}"
-            ), "Invalid input string"
+            assert input_str.startswith("{") and input_str.endswith("}"), (
+                "Invalid input string"
+            )
             input_str_set_interior: str = input_str.strip("{}").strip()
             if len(input_str_set_interior) == 0:
                 return cls.get_empty()
@@ -437,7 +439,7 @@ class Interval:
 
         return max(clamped_min, min(value, clamped_max))
 
-    def intersection(self, other: Interval) -> Optional[Interval]:
+    def intersection(self, other: Interval) -> Interval:
         if not isinstance(other, Interval):
             raise TypeError("Can only intersect with another Interval")
 
