@@ -13,9 +13,15 @@ import typing
 import warnings
 from typing import Any, Iterable, Literal, Optional, Sequence
 
-import numpy as np
+try:
+    import numpy as np
+except ImportError as e:
+    warnings.warn(
+        f"numpy is not installed, array serialization will not work: \n{e}",
+        ImportWarning,
+    )
 
-from muutils.json_serialize.util import JSONitem
+from muutils.json_serialize.util import _FORMAT_KEY, JSONitem
 
 # pylint: disable=unused-argument
 
@@ -69,7 +75,7 @@ def serialize_array(
     for `array_list_meta`, `array_hex_meta`, and `array_b64_meta`, the serialized object is:
     ```
     {
-        "__format__": <array_list_meta|array_hex_meta>,
+        _FORMAT_KEY: <array_list_meta|array_hex_meta>,
         "shape": arr.shape,
         "dtype": str(arr.dtype),
         "data": <arr.tolist()|arr.tobytes().hex()|base64.b64encode(arr.tobytes()).decode()>,
@@ -98,14 +104,14 @@ def serialize_array(
     # handle zero-dimensional arrays
     if len(arr.shape) == 0:
         return {
-            "__format__": f"{arr_type}:zero_dim",
+            _FORMAT_KEY: f"{arr_type}:zero_dim",
             "data": arr.item(),
             **arr_metadata(arr),
         }
 
     if array_mode == "array_list_meta":
         return {
-            "__format__": f"{arr_type}:array_list_meta",
+            _FORMAT_KEY: f"{arr_type}:array_list_meta",
             "data": arr_np.tolist(),
             **arr_metadata(arr_np),
         }
@@ -113,13 +119,13 @@ def serialize_array(
         return arr_np.tolist()
     elif array_mode == "array_hex_meta":
         return {
-            "__format__": f"{arr_type}:array_hex_meta",
+            _FORMAT_KEY: f"{arr_type}:array_hex_meta",
             "data": arr_np.tobytes().hex(),
             **arr_metadata(arr_np),
         }
     elif array_mode == "array_b64_meta":
         return {
-            "__format__": f"{arr_type}:array_b64_meta",
+            _FORMAT_KEY: f"{arr_type}:array_b64_meta",
             "data": base64.b64encode(arr_np.tobytes()).decode(),
             **arr_metadata(arr_np),
         }
@@ -133,7 +139,7 @@ def infer_array_mode(arr: JSONitem) -> ArrayMode:
     assumes the array was serialized via `serialize_array()`
     """
     if isinstance(arr, typing.Mapping):
-        fmt: str = arr.get("__format__", "")
+        fmt: str = arr.get(_FORMAT_KEY, "")  # type: ignore
         if fmt.endswith(":array_list_meta"):
             if not isinstance(arr["data"], Iterable):
                 raise ValueError(f"invalid list format: {type(arr['data']) = }\t{arr}")
@@ -175,37 +181,33 @@ def load_array(arr: JSONitem, array_mode: Optional[ArrayMode] = None) -> Any:
 
     # actually load the array
     if array_mode == "array_list_meta":
-        assert isinstance(
-            arr, typing.Mapping
-        ), f"invalid list format: {type(arr) = }\n{arr = }"
-
-        data = np.array(arr["data"], dtype=arr["dtype"])
-        if tuple(arr["shape"]) != tuple(data.shape):
+        assert isinstance(arr, typing.Mapping), (
+            f"invalid list format: {type(arr) = }\n{arr = }"
+        )
+        data = np.array(arr["data"], dtype=arr["dtype"])  # type: ignore
+        if tuple(arr["shape"]) != tuple(data.shape):  # type: ignore
             raise ValueError(f"invalid shape: {arr}")
         return data
 
     elif array_mode == "array_hex_meta":
-        assert isinstance(
-            arr, typing.Mapping
-        ), f"invalid list format: {type(arr) = }\n{arr = }"
-
-        data = np.frombuffer(bytes.fromhex(arr["data"]), dtype=arr["dtype"])
-        return data.reshape(arr["shape"])
+        assert isinstance(arr, typing.Mapping), (
+            f"invalid list format: {type(arr) = }\n{arr = }"
+        )
+        data = np.frombuffer(bytes.fromhex(arr["data"]), dtype=arr["dtype"])  # type: ignore
+        return data.reshape(arr["shape"])  # type: ignore
 
     elif array_mode == "array_b64_meta":
-        assert isinstance(
-            arr, typing.Mapping
-        ), f"invalid list format: {type(arr) = }\n{arr = }"
-
-        data = np.frombuffer(base64.b64decode(arr["data"]), dtype=arr["dtype"])
-        return data.reshape(arr["shape"])
+        assert isinstance(arr, typing.Mapping), (
+            f"invalid list format: {type(arr) = }\n{arr = }"
+        )
+        data = np.frombuffer(base64.b64decode(arr["data"]), dtype=arr["dtype"])  # type: ignore
+        return data.reshape(arr["shape"])  # type: ignore
 
     elif array_mode == "list":
-        assert isinstance(
-            arr, typing.Sequence
-        ), f"invalid list format: {type(arr) = }\n{arr = }"
-
-        return np.array(arr)
+        assert isinstance(arr, typing.Sequence), (
+            f"invalid list format: {type(arr) = }\n{arr = }"
+        )
+        return np.array(arr)  # type: ignore
     elif array_mode == "external":
         # assume ZANJ has taken care of it
         assert isinstance(arr, typing.Mapping)
@@ -217,7 +219,7 @@ def load_array(arr: JSONitem, array_mode: Optional[ArrayMode] = None) -> Any:
     elif array_mode == "zero_dim":
         assert isinstance(arr, typing.Mapping)
         data = np.array(arr["data"])
-        if tuple(arr["shape"]) != tuple(data.shape):
+        if tuple(arr["shape"]) != tuple(data.shape):  # type: ignore
             raise ValueError(f"invalid shape: {arr}")
         return data
     else:
