@@ -17,7 +17,7 @@ and then you can call `my_obj.serialize()` to get a dict that can be serialized
     >>> my_obj = MyClass(a=1, b="q")
     >>> s = json.dumps(my_obj.serialize())
     >>> s
-    '{"__format__": "MyClass(SerializableDataclass)", "a": 1, "b": "q"}'
+    '{_FORMAT_KEY: "MyClass(SerializableDataclass)", "a": 1, "b": "q"}'
     >>> read_obj = MyClass.load(json.loads(s))
     >>> read_obj == my_obj
     True
@@ -42,7 +42,7 @@ which gives us:
     >>> nc = NestedClass(x="q", y=MyClass(a=1, b="q"), act_fun=torch.nn.Sigmoid())
     >>> s = json.dumps(nc.serialize())
     >>> s
-    '{"__format__": "NestedClass(SerializableDataclass)", "x": "q", "y": {"__format__": "MyClass(SerializableDataclass)", "a": 1, "b": "q"}, "act_fun": "Sigmoid"}'
+    '{_FORMAT_KEY: "NestedClass(SerializableDataclass)", "x": "q", "y": {_FORMAT_KEY: "MyClass(SerializableDataclass)", "a": 1, "b": "q"}, "act_fun": "Sigmoid"}'
     >>> read_nc = NestedClass.load(json.loads(s))
     >>> read_nc == nc
     True
@@ -66,42 +66,20 @@ from muutils.json_serialize.serializable_field import (
     SerializableField,
     serializable_field,
 )
-from muutils.json_serialize.util import array_safe_eq, dc_eq
+from muutils.json_serialize.util import _FORMAT_KEY, array_safe_eq, dc_eq
 
 # pylint: disable=bad-mcs-classmethod-argument, too-many-arguments, protected-access
 
-
-def _dataclass_transform_mock(
-    *,
-    eq_default: bool = True,
-    order_default: bool = False,
-    kw_only_default: bool = False,
-    frozen_default: bool = False,
-    field_specifiers: tuple[type[Any] | typing.Callable[..., Any], ...] = (),
-    **kwargs: Any,
-) -> typing.Callable:
-    "mock `typing.dataclass_transform` for python <3.11"
-
-    def decorator(cls_or_fn):
-        cls_or_fn.__dataclass_transform__ = {
-            "eq_default": eq_default,
-            "order_default": order_default,
-            "kw_only_default": kw_only_default,
-            "frozen_default": frozen_default,
-            "field_specifiers": field_specifiers,
-            "kwargs": kwargs,
-        }
-        return cls_or_fn
-
-    return decorator
-
-
-dataclass_transform: typing.Callable
-if sys.version_info < (3, 11):
-    dataclass_transform = _dataclass_transform_mock
-else:
-    dataclass_transform = typing.dataclass_transform
-
+# this is quite horrible, but unfortunately mypy fails if we try to assign to `dataclass_transform` directly
+# and every time we try to init a serializable dataclass it says the argument doesnt exist
+try:
+    try:
+        # type ignore here for legacy versions
+        from typing import dataclass_transform  # type: ignore[attr-defined]
+    except Exception:
+        from typing_extensions import dataclass_transform
+except Exception:
+    from muutils.json_serialize.dataclass_transform_mock import dataclass_transform
 
 T = TypeVar("T")
 
@@ -139,18 +117,19 @@ def zanj_register_loader_serializable_dataclass(cls: typing.Type[T]):
                 register_loader_handler,
             )
         except ImportError:
-            warnings.warn(
-                "ZANJ not installed, cannot register serializable dataclass loader. ZANJ can be found at https://github.com/mivanit/ZANJ or installed via `pip install zanj`",
-                ZanjMissingWarning,
-            )
+            # NOTE: if ZANJ is not installed, then failing to register the loader handler doesnt matter
+            # warnings.warn(
+            #     "ZANJ not installed, cannot register serializable dataclass loader. ZANJ can be found at https://github.com/mivanit/ZANJ or installed via `pip install zanj`",
+            #     ZanjMissingWarning,
+            # )
             return
 
     _format: str = f"{cls.__name__}(SerializableDataclass)"
     lh: LoaderHandler = LoaderHandler(
         check=lambda json_item, path=None, z=None: (  # type: ignore
             isinstance(json_item, dict)
-            and "__format__" in json_item
-            and json_item["__format__"].startswith(_format)
+            and _FORMAT_KEY in json_item
+            and json_item[_FORMAT_KEY].startswith(_format)
         ),
         load=lambda json_item, path=None, z=None: cls.load(json_item),  # type: ignore
         uid=_format,
@@ -215,9 +194,9 @@ def SerializableDataclass__validate_field_type(
         )
         return True
 
-    assert isinstance(
-        _field, SerializableField
-    ), f"Field '{_field.name = }' on class {self.__class__ = } is not a SerializableField, but a {type(_field) = }"
+    assert isinstance(_field, SerializableField), (
+        f"Field '{_field.name = }' on class {self.__class__ = } is not a SerializableField, but a {type(_field) = }"
+    )
 
     # get field type hints
     try:
@@ -334,7 +313,7 @@ class SerializableDataclass(abc.ABC):
         >>> my_obj = MyClass(a=1, b="q")
         >>> s = json.dumps(my_obj.serialize())
         >>> s
-        '{"__format__": "MyClass(SerializableDataclass)", "a": 1, "b": "q"}'
+        '{_FORMAT_KEY: "MyClass(SerializableDataclass)", "a": 1, "b": "q"}'
         >>> read_obj = MyClass.load(json.loads(s))
         >>> read_obj == my_obj
         True
@@ -359,7 +338,7 @@ class SerializableDataclass(abc.ABC):
         >>> nc = NestedClass(x="q", y=MyClass(a=1, b="q"), act_fun=torch.nn.Sigmoid())
         >>> s = json.dumps(nc.serialize())
         >>> s
-        '{"__format__": "NestedClass(SerializableDataclass)", "x": "q", "y": {"__format__": "MyClass(SerializableDataclass)", "a": 1, "b": "q"}, "act_fun": "Sigmoid"}'
+        '{_FORMAT_KEY: "NestedClass(SerializableDataclass)", "x": "q", "y": {_FORMAT_KEY: "MyClass(SerializableDataclass)", "a": 1, "b": "q"}, "act_fun": "Sigmoid"}'
         >>> read_nc = NestedClass.load(json.loads(s))
         >>> read_nc == nc
         True
@@ -429,7 +408,7 @@ class SerializableDataclass(abc.ABC):
          - `ValueError` : if the instances are `dataclasses.dataclass` but not `SerializableDataclass`
         """
         # match types
-        if type(self) != type(other):
+        if type(self) is not type(other):
             raise ValueError(
                 f"Instances must be of the same type, but got {type(self) = } and {type(other) = }"
             )
@@ -438,8 +417,11 @@ class SerializableDataclass(abc.ABC):
         diff_result: dict = {}
 
         # if they are the same, return the empty diff
-        if self == other:
-            return diff_result
+        try:
+            if self == other:
+                return diff_result
+        except Exception:
+            pass
 
         # if we are working with serialized data, serialize the instances
         if of_serialized:
@@ -567,6 +549,12 @@ class FieldLoadingError(FieldError):
     pass
 
 
+class FieldTypeMismatchError(FieldError, TypeError):
+    "error when a field type does not match the type hint"
+
+    pass
+
+
 @dataclass_transform(
     field_specifiers=(serializable_field, SerializableField),
 )
@@ -584,13 +572,14 @@ def serializable_dataclass(
     register_handler: bool = True,
     on_typecheck_error: ErrorMode = _DEFAULT_ON_TYPECHECK_ERROR,
     on_typecheck_mismatch: ErrorMode = _DEFAULT_ON_TYPECHECK_MISMATCH,
+    methods_no_override: list[str] | None = None,
     **kwargs,
 ):
-    """decorator to make a dataclass serializable. must also make it inherit from `SerializableDataclass`
+    """decorator to make a dataclass serializable. **must also make it inherit from `SerializableDataclass`!!**
 
     types will be validated (like pydantic) unless `on_typecheck_mismatch` is set to `ErrorMode.IGNORE`
 
-    behavior of most kwargs matches that of `dataclasses.dataclass`, but with some additional kwargs
+    behavior of most kwargs matches that of `dataclasses.dataclass`, but with some additional kwargs. any kwargs not listed here are passed to `dataclasses.dataclass`
 
     Returns the same class as was passed in, with dunder methods added based on the fields defined in the class.
 
@@ -606,44 +595,69 @@ def serializable_dataclass(
     ```
     ```python
     >>> Myclass(a=1, b="q").serialize()
-    {'__format__': 'Myclass(SerializableDataclass)', 'a': 1, 'b': 'q'}
+    {_FORMAT_KEY: 'Myclass(SerializableDataclass)', 'a': 1, 'b': 'q'}
     ```
 
     # Parameters:
-     - `_cls : _type_`
+
+    - `_cls : _type_`
        class to decorate. don't pass this arg, just use this as a decorator
        (defaults to `None`)
-     - `init : bool`
+    - `init : bool`
+       whether to add an `__init__` method
+       *(passed to dataclasses.dataclass)*
        (defaults to `True`)
-     - `repr : bool`
+    - `repr : bool`
+       whether to add a `__repr__` method
+       *(passed to dataclasses.dataclass)*
        (defaults to `True`)
-     - `order : bool`
+    - `order : bool`
+       whether to add rich comparison methods
+       *(passed to dataclasses.dataclass)*
        (defaults to `False`)
-     - `unsafe_hash : bool`
+    - `unsafe_hash : bool`
+       whether to add a `__hash__` method
+       *(passed to dataclasses.dataclass)*
        (defaults to `False`)
-     - `frozen : bool`
+    - `frozen : bool`
+       whether to make the class frozen
+       *(passed to dataclasses.dataclass)*
        (defaults to `False`)
-     - `properties_to_serialize : Optional[list[str]]`
-       **SerializableDataclass only:** which properties to add to the serialized data dict
+    - `properties_to_serialize : Optional[list[str]]`
+       which properties to add to the serialized data dict
+       **SerializableDataclass only**
        (defaults to `None`)
-     - `register_handler : bool`
-        **SerializableDataclass only:** if true, register the class with ZANJ for loading
-       (defaults to `True`)
-     - `on_typecheck_error : ErrorMode`
-        **SerializableDataclass only:** what to do if type checking throws an exception (except, warn, ignore). If `ignore` and an exception is thrown, type validation will still return false
-     - `on_typecheck_mismatch : ErrorMode`
-        **SerializableDataclass only:** what to do if a type mismatch is found (except, warn, ignore). If `ignore`, type validation will return `True`
+    - `register_handler : bool`
+        if true, register the class with ZANJ for loading
+        **SerializableDataclass only**
+        (defaults to `True`)
+    - `on_typecheck_error : ErrorMode`
+        what to do if type checking throws an exception (except, warn, ignore). If `ignore` and an exception is thrown, type validation will still return false
+        **SerializableDataclass only**
+    - `on_typecheck_mismatch : ErrorMode`
+        what to do if a type mismatch is found (except, warn, ignore). If `ignore`, type validation will return `True`
+        **SerializableDataclass only**
+    - `methods_no_override : list[str]|None`
+        list of methods that should not be overridden by the decorator
+        by default, `__eq__`, `serialize`, `load`, and `validate_fields_types` are overridden by this function,
+        but you can disable this if you'd rather write your own. `dataclasses.dataclass` might still overwrite these, and those options take precedence
+        **SerializableDataclass only**
+        (defaults to `None`)
+    - `**kwargs`
+        *(passed to dataclasses.dataclass)*
 
     # Returns:
-     - `_type_`
+
+    - `_type_`
        the decorated class
 
     # Raises:
-     - `KWOnlyError` : only raised if `kw_only` is `True` and python version is <3.9, since `dataclasses.dataclass` does not support this
-     - `NotSerializableFieldException` : if a field is not a `SerializableField`
-     - `FieldSerializationError` : if there is an error serializing a field
-     - `AttributeError` : if a property is not found on the class
-     - `FieldLoadingError` : if there is an error loading a field
+
+    - `KWOnlyError` : only raised if `kw_only` is `True` and python version is <3.9, since `dataclasses.dataclass` does not support this
+    - `NotSerializableFieldException` : if a field is not a `SerializableField`
+    - `FieldSerializationError` : if there is an error serializing a field
+    - `AttributeError` : if a property is not found on the class
+    - `FieldLoadingError` : if there is an error loading a field
     """
     # -> Union[Callable[[Type[T]], Type[T]], Type[T]]:
     on_typecheck_error = ErrorMode.from_any(on_typecheck_error)
@@ -671,7 +685,9 @@ def serializable_dataclass(
         if sys.version_info < (3, 10):
             if "kw_only" in kwargs:
                 if kwargs["kw_only"] == True:  # noqa: E712
-                    raise KWOnlyError("kw_only is not supported in python >=3.9")
+                    raise KWOnlyError(
+                        "kw_only is not supported in python < 3.10, but if you pass a `False` value, it will be ignored"
+                    )
                 else:
                     del kwargs["kw_only"]
 
@@ -696,7 +712,7 @@ def serializable_dataclass(
         # ======================================================================
         def serialize(self) -> dict[str, Any]:
             result: dict[str, Any] = {
-                "__format__": f"{self.__class__.__name__}(SerializableDataclass)"
+                _FORMAT_KEY: f"{self.__class__.__name__}(SerializableDataclass)"
             }
             # for each field in the class
             for field in dataclasses.fields(self):  # type: ignore[arg-type]
@@ -763,9 +779,9 @@ def serializable_dataclass(
             if isinstance(data, cls):
                 return data
 
-            assert isinstance(
-                data, typing.Mapping
-            ), f"When loading {cls.__name__ = } expected a Mapping, but got {type(data) = }:\n{data = }"
+            assert isinstance(data, typing.Mapping), (
+                f"When loading {cls.__name__ = } expected a Mapping, but got {type(data) = }:\n{data = }"
+            )
 
             cls_type_hints: dict[str, Any] = get_cls_type_hints(cls)
 
@@ -775,9 +791,9 @@ def serializable_dataclass(
             # iterate over the fields of the class
             for field in dataclasses.fields(cls):
                 # check if the field is a SerializableField
-                assert isinstance(
-                    field, SerializableField
-                ), f"Field '{field.name}' on class {cls.__name__} is not a SerializableField, but a {type(field)}. this state should be inaccessible, please report this bug!\nhttps://github.com/mivanit/muutils/issues/new"
+                assert isinstance(field, SerializableField), (
+                    f"Field '{field.name}' on class {cls.__name__} is not a SerializableField, but a {type(field)}. this state should be inaccessible, please report this bug!\nhttps://github.com/mivanit/muutils/issues/new"
+                )
 
                 # check if the field is in the data and if it should be initialized
                 if (field.name in data) and field.init:
@@ -818,21 +834,64 @@ def serializable_dataclass(
 
             # validate the types of the fields if needed
             if on_typecheck_mismatch != ErrorMode.IGNORE:
-                output.validate_fields_types(on_typecheck_error=on_typecheck_error)
+                fields_valid: dict[str, bool] = (
+                    SerializableDataclass__validate_fields_types__dict(
+                        output,
+                        on_typecheck_error=on_typecheck_error,
+                    )
+                )
+
+                # if there are any fields that are not valid, raise an error
+                if not all(fields_valid.values()):
+                    msg: str = (
+                        f"Type mismatch in fields of {cls.__name__}:\n"
+                        + "\n".join(
+                            [
+                                f"{k}:\texpected {cls_type_hints[k] = }, but got value {getattr(output, k) = }, {type(getattr(output, k)) = }"
+                                for k, v in fields_valid.items()
+                                if not v
+                            ]
+                        )
+                    )
+
+                    on_typecheck_mismatch.process(
+                        msg, except_cls=FieldTypeMismatchError
+                    )
 
             # return the new instance
             return output
 
-        # mypy says "Type cannot be declared in assignment to non-self attribute" so thats why I've left the hints in the comments
-        # type is `Callable[[T], dict]`
-        cls.serialize = serialize  # type: ignore[attr-defined]
-        # type is `Callable[[dict], T]`
-        cls.load = load  # type: ignore[attr-defined]
-        # type is `Callable[[T, ErrorMode], bool]`
-        cls.validate_fields_types = SerializableDataclass__validate_fields_types  # type: ignore[attr-defined]
+        _methods_no_override: set[str]
+        if methods_no_override is None:
+            _methods_no_override = set()
+        else:
+            _methods_no_override = set(methods_no_override)
 
-        # type is `Callable[[T, T], bool]`
-        cls.__eq__ = lambda self, other: dc_eq(self, other)  # type: ignore[assignment]
+        if _methods_no_override - {
+            "__eq__",
+            "serialize",
+            "load",
+            "validate_fields_types",
+        }:
+            warnings.warn(
+                f"Unknown methods in `methods_no_override`: {_methods_no_override = }"
+            )
+
+        # mypy says "Type cannot be declared in assignment to non-self attribute" so thats why I've left the hints in the comments
+        if "serialize" not in _methods_no_override:
+            # type is `Callable[[T], dict]`
+            cls.serialize = serialize  # type: ignore[attr-defined]
+        if "load" not in _methods_no_override:
+            # type is `Callable[[dict], T]`
+            cls.load = load  # type: ignore[attr-defined]
+
+        if "validate_field_type" not in _methods_no_override:
+            # type is `Callable[[T, ErrorMode], bool]`
+            cls.validate_fields_types = SerializableDataclass__validate_fields_types  # type: ignore[attr-defined]
+
+        if "__eq__" not in _methods_no_override:
+            # type is `Callable[[T, T], bool]`
+            cls.__eq__ = lambda self, other: dc_eq(self, other)  # type: ignore[assignment]
 
         # Register the class with ZANJ
         if register_handler:
