@@ -30,6 +30,7 @@ class SerializableField(dataclasses.Field):
         "hash",
         "init",
         "compare",
+        "doc",
         "metadata",
         "kw_only",
         "_field_type",  # Private: not to be used by user code.
@@ -52,6 +53,7 @@ class SerializableField(dataclasses.Field):
         repr: bool = True,
         hash: Optional[bool] = None,
         compare: bool = True,
+        doc: str | None = None,
         # TODO: add field for custom comparator (such as serializing)
         metadata: Optional[types.MappingProxyType] = None,
         kw_only: Union[bool, dataclasses._MISSING_TYPE] = dataclasses.MISSING,
@@ -82,6 +84,10 @@ class SerializableField(dataclasses.Field):
         else:
             super_kwargs["metadata"] = types.MappingProxyType({})
 
+        # only pass `doc` to super if python >=3.14
+        if sys.version_info >= (3, 14):
+            super_kwargs["doc"] = doc
+
         # special check, kw_only is not supported in python <3.9 and `dataclasses.MISSING` is truthy
         if sys.version_info < (3, 10):
             if super_kwargs["kw_only"] == True:  # noqa: E712
@@ -92,6 +98,10 @@ class SerializableField(dataclasses.Field):
         # actually init the super class
         super().__init__(**super_kwargs)  # type: ignore[call-arg]
 
+        # init doc if python <3.14
+        if sys.version_info < (3, 14):
+            self.doc: str | None = doc
+
         # now init the new fields
         self.serialize: bool = serialize
         self.serialization_fn: Optional[Callable[[Any], Any]] = serialization_fn
@@ -118,6 +128,7 @@ class SerializableField(dataclasses.Field):
             repr=field.repr,
             hash=field.hash,
             compare=field.compare,
+            doc=getattr(field, "doc", None),  # `doc` added in python <3.14
             metadata=field.metadata,
             kw_only=getattr(field, "kw_only", dataclasses.MISSING),  # for python <3.9
             serialize=field.repr,  # serialize if it's going to be repr'd
@@ -131,7 +142,7 @@ Sfield_T = TypeVar("Sfield_T")
 
 
 @overload
-def serializable_field(
+def serializable_field(  # only `default_factory` is provided
     *_args,
     default_factory: Callable[[], Sfield_T],
     default: dataclasses._MISSING_TYPE = dataclasses.MISSING,
@@ -139,6 +150,7 @@ def serializable_field(
     repr: bool = True,
     hash: Optional[bool] = None,
     compare: bool = True,
+    doc: str | None = None,
     metadata: Optional[types.MappingProxyType] = None,
     kw_only: Union[bool, dataclasses._MISSING_TYPE] = dataclasses.MISSING,
     serialize: bool = True,
@@ -149,7 +161,7 @@ def serializable_field(
     **kwargs: Any,
 ) -> Sfield_T: ...
 @overload
-def serializable_field(
+def serializable_field(  # only `default` is provided
     *_args,
     default: Sfield_T,
     default_factory: dataclasses._MISSING_TYPE = dataclasses.MISSING,
@@ -157,6 +169,7 @@ def serializable_field(
     repr: bool = True,
     hash: Optional[bool] = None,
     compare: bool = True,
+    doc: str | None = None,
     metadata: Optional[types.MappingProxyType] = None,
     kw_only: Union[bool, dataclasses._MISSING_TYPE] = dataclasses.MISSING,
     serialize: bool = True,
@@ -167,7 +180,7 @@ def serializable_field(
     **kwargs: Any,
 ) -> Sfield_T: ...
 @overload
-def serializable_field(
+def serializable_field(  # both `default` and `default_factory` are MISSING
     *_args,
     default: dataclasses._MISSING_TYPE = dataclasses.MISSING,
     default_factory: dataclasses._MISSING_TYPE = dataclasses.MISSING,
@@ -175,6 +188,7 @@ def serializable_field(
     repr: bool = True,
     hash: Optional[bool] = None,
     compare: bool = True,
+    doc: str | None = None,
     metadata: Optional[types.MappingProxyType] = None,
     kw_only: Union[bool, dataclasses._MISSING_TYPE] = dataclasses.MISSING,
     serialize: bool = True,
@@ -184,7 +198,7 @@ def serializable_field(
     custom_typecheck_fn: Optional[Callable[[type], bool]] = None,
     **kwargs: Any,
 ) -> Any: ...
-def serializable_field(
+def serializable_field(  # general implementation
     *_args,
     default: Union[Any, dataclasses._MISSING_TYPE] = dataclasses.MISSING,
     default_factory: Union[Any, dataclasses._MISSING_TYPE] = dataclasses.MISSING,
@@ -192,6 +206,7 @@ def serializable_field(
     repr: bool = True,
     hash: Optional[bool] = None,
     compare: bool = True,
+    doc: str | None = None,
     metadata: Optional[types.MappingProxyType] = None,
     kw_only: Union[bool, dataclasses._MISSING_TYPE] = dataclasses.MISSING,
     serialize: bool = True,
@@ -211,6 +226,7 @@ def serializable_field(
     repr: bool = True,
     hash: Optional[bool] = None,
     compare: bool = True,
+    doc: str | None = None, # new in python 3.14. can alternately pass `description` to match pydantic, but this is discouraged
     metadata: types.MappingProxyType | None = None,
     kw_only: bool | dataclasses._MISSING_TYPE = dataclasses.MISSING,
     # ----------------------------------------------------------------------
@@ -228,6 +244,8 @@ def serializable_field(
     - `serialization_fn`: function taking the instance of the field and returning a serializable object. If not provided, will iterate through the `SerializerHandler`s defined in `muutils.json_serialize.json_serialize`
     - `loading_fn`: function taking the serialized object and returning the instance of the field. If not provided, will take object as-is.
     - `deserialize_fn`: new alternative to `loading_fn`. takes only the field's value, not the whole class. if both `loading_fn` and `deserialize_fn` are provided, an error will be raised.
+    - `assert_type`: whether to assert the type of the field when loading. if `False`, will not check the type of the field.
+    - `custom_typecheck_fn`: function taking the type of the field and returning whether the type itself is valid. if not provided, will use the default type checking.
 
     # Gotchas:
     - `loading_fn` takes the dict of the **class**, not the field. if you wanted a `loading_fn` that does nothing, you'd write:
@@ -255,8 +273,23 @@ def serializable_field(
     note that if not using ZANJ, and you have a class inside a container, you MUST provide
     `serialization_fn` and `loading_fn` to serialize and load the container.
     ZANJ will automatically do this for you.
+
+    # TODO: `custom_value_check_fn`: function taking the value of the field and returning whether the value itself is valid. if not provided, any value is valid as long as it passes the type test
     """
     assert len(_args) == 0, f"unexpected positional arguments: {_args}"
+
+    if "description" in kwargs:
+        import warnings
+
+        warnings.warn(
+            "`description` is deprecated, use `doc` instead",
+            DeprecationWarning,
+        )
+        if doc is not None:
+            err_msg: str = f"cannot pass both `doc` and `description`: {doc=}, {kwargs['description']=}"
+            raise ValueError(err_msg)
+        doc = kwargs.pop("description")
+
     return SerializableField(
         default=default,
         default_factory=default_factory,
