@@ -2,11 +2,13 @@
 
 - `SimpleLogger` is an extremely simple logger that can write to both console and a file
 - `Logger` class handles levels in a slightly different way than default python `logging`,
-	and also has "streams" which allow for different sorts of output in the same logger
-	this was mostly made with training models in mind and storing both metadata and loss
+        and also has "streams" which allow for different sorts of output in the same logger
+        this was mostly made with training models in mind and storing both metadata and loss
 - `TimerContext` is a context manager that can be used to time the duration of a block of code
 """
 
+from __future__ import annotations
+
 import json
 import time
 import typing
@@ -126,7 +128,7 @@ class Logger(SimpleLogger):
             )
 
         # check alias duplicates
-        alias_set: set[str] = set()
+        alias_set: set[str | None] = set()
         for stream in self._streams.values():
             for alias in stream.aliases:
                 if alias in alias_set:
@@ -193,7 +195,7 @@ class Logger(SimpleLogger):
                 else:
                     lvl = self._default_level
 
-        assert not lvl is None, "lvl should not be None at this point"
+        assert lvl is not None, "lvl should not be None at this point"
 
         # print to console with formatting
         # ========================================
