@@ -35,7 +35,6 @@ TYPE_TO_JAX_DTYPE: dict = {
     np.bool_: jaxtyping.Bool,
     torch.bool: jaxtyping.Bool,
     # numpy float
-    np.float_: jaxtyping.Float,
     np.float16: jaxtyping.Float,
     np.float32: jaxtyping.Float,
     np.float64: jaxtyping.Float,
@@ -43,7 +42,6 @@ TYPE_TO_JAX_DTYPE: dict = {
     np.single: jaxtyping.Float,
     np.double: jaxtyping.Float,
     # numpy int
-    np.int_: jaxtyping.Int,
     np.int8: jaxtyping.Int,
     np.int16: jaxtyping.Int,
     np.int32: jaxtyping.Int,
@@ -70,13 +68,19 @@ TYPE_TO_JAX_DTYPE: dict = {
 }
 "dict mapping python, numpy, and torch types to `jaxtyping` types"
 
+# we check for version here, so it shouldn't error
+if np.version.version < "2.0.0":
+    TYPE_TO_JAX_DTYPE[np.float_] = jaxtyping.Float  # type: ignore[attr-defined]
+    TYPE_TO_JAX_DTYPE[np.int_] = jaxtyping.Int  # type: ignore[attr-defined]
+
 
 # TODO: add proper type annotations to this signature
+# TODO: maybe get rid of this altogether?
 def jaxtype_factory(
     name: str,
     array_type: type,
     default_jax_dtype=jaxtyping.Float,
-    legacy_mode: ErrorMode = ErrorMode.WARN,
+    legacy_mode: typing.Union[ErrorMode, str] = ErrorMode.WARN,
 ) -> type:
     """usage:
     ```
@@ -84,7 +88,7 @@ def jaxtype_factory(
     x: ATensor["dim1 dim2", np.float32]
     ```
     """
-    legacy_mode = ErrorMode.from_any(legacy_mode)
+    legacy_mode_ = ErrorMode.from_any(legacy_mode)
 
     class _BaseArray:
         """jaxtyping shorthand
@@ -114,7 +118,7 @@ def jaxtype_factory(
             )
 
         @typing._tp_cache  # type: ignore
-        def __class_getitem__(cls, params: typing.Union[str, tuple]) -> type:
+        def __class_getitem__(cls, params: typing.Union[str, tuple]) -> type:  # type: ignore
             # MyTensor["dim1 dim2"]
             if isinstance(params, str):
                 return default_jax_dtype[array_type, params]
@@ -130,7 +134,7 @@ def jaxtype_factory(
                     return TYPE_TO_JAX_DTYPE[params[1]][array_type, params[0]]
 
                 elif isinstance(params[0], tuple):
-                    legacy_mode.process(
+                    legacy_mode_.process(
                         f"legacy type annotation was used:\n{cls.param_info(params) = }",
                         except_cls=Exception,
                     )
@@ -234,7 +238,6 @@ DTYPE_LIST: list = [
         # numpy
         # ----------
         # floats
-        np.float_,
         np.float16,
         np.float32,
         np.float64,
@@ -249,7 +252,6 @@ DTYPE_LIST: list = [
         np.int16,
         np.int32,
         np.int64,
-        np.int_,
         np.longlong,
         np.short,
         # simplest
@@ -259,6 +261,9 @@ DTYPE_LIST: list = [
 ]
 "list of all the python, numpy, and torch numerical types I could think of"
 
+if np.version.version < "2.0.0":
+    DTYPE_LIST.extend([np.float_, np.int_])  # type: ignore[attr-defined]
+
 DTYPE_MAP: dict = {
     **{str(x): x for x in DTYPE_LIST},
     **{dtype.__name__: dtype for dtype in DTYPE_LIST if dtype.__module__ == "numpy"},
